@@ -10,13 +10,13 @@ no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
 use parent 'Class::Accessor';
 
-our $VERSION = '4.00';
+our $VERSION = '4.01';
 
 Travel::Status::DE::HAFAS::Journey->mk_ro_accessors(
 	qw(datetime sched_datetime rt_datetime
 	  is_cancelled is_partially_cancelled
 	  platform sched_platform rt_platform operator
-	  id name type type_long number line load delay
+	  id name type type_long class number line load delay
 	  route_end route_start origin destination direction)
 );
 
@@ -86,6 +86,8 @@ sub new {
 		}
 	}
 
+	my $class = $product->{cls};
+
 	my @stops;
 	for my $stop ( @{ $journey->{stopL} // [] } ) {
 		my $loc       = $locL[ $stop->{locX} ];
@@ -169,6 +171,7 @@ sub new {
 		line                   => $line_no,
 		type                   => $cat,
 		type_long              => $catlong,
+		class                  => $class,
 		operator               => $operator,
 		direction              => $direction,
 		is_cancelled           => $is_cancelled,
@@ -347,7 +350,7 @@ journey received by Travel::Status::DE::HAFAS
 
 =head1 VERSION
 
-version 4.00
+version 4.01
 
 =head1 DESCRIPTION
 
@@ -379,6 +382,12 @@ or "STR" for tram / StraE<szlig>enbahn.
 
 Returns the long type of this journey, e.g. "S-Bahn" or "Regional-Express".
 
+=item $journey->class
+
+Returns an integer identifying the the mode of transport class.
+Semantics depend on backend, e.g. "1" and "2" for long-distance trains and
+"4" and "8" for region trains.
+
 =item $journey->line
 
 Returns the line identifier, or undef if it is unknown.
